MapProvider class
Methods
-
addGpsLocation({TrackingMode? mode = TrackingMode.PLANAR})
→ void
-
-
addListener(VoidCallback listener)
→ void
-
Register a closure to be called when the object changes.
inherited
-
calculateDistance(LatLng firstLocation, LatLng secondLocation)
→ Future<String>
-
Calculate distance between two location
-
changeCameraPosition(LatLng location)
→ void
-
Function to change camera position
-
changeEditMode()
→ void
-
Function to change toggle edit mode
-
createDistanceMarker(LatLng startLocation, LatLng _location)
→ Future<void>
-
Function to create distance marker
-
createEndLoc(LatLng startLocation, LatLng _location)
→ Future<void>
-
Function to set end location marker
-
dispose()
→ void
-
Discards any resources used by the object.
inherited
-
getCenterLatLong(List<LatLng> latLongList)
→ Future<LatLng>
-
Function to get center location between two coordinate
-
getPolyColor(Color? color)
→ Future<Color?>
-
Assign polygon color
-
getUint8List(GlobalKey<State<StatefulWidget>> widgetKey)
→ Future<Uint8List?>
-
Converting Widget to PNG
-
initCamera(bool autoEditMode, bool? pointDist, {LatLng? targetCameraPosition, bool? dragMarker})
→ void
-
------------------------///
FUNCTION SECTIONS ///
------------------------///
Function to initialize camera
-
initLocation()
→ Future<void>
-
Function to get current locations if permission
available, otherwise set default location
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners()
→ void
-
Call all the registered listeners.
inherited
-
onMapCreated(GoogleMapController controller)
→ void
-
Function to handle when maps created
-
onTapMap(LatLng _location, {TrackingMode? mode = TrackingMode.PLANAR})
→ void
-
Function to handle onTap Map and get location
-
removeListener(VoidCallback listener)
→ void
-
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
removeMarker(LatLng? _loc)
→ Future<void>
-
-
removeMarkerByLatlong(LatLng _location)
→ void
-
Remove marker by latlong
-
saveTracking(BuildContext context)
→ void
-
Function to save tracking points to database
-
setMarkerLocation(String id, LatLng _location, Uint8List? markerIcon, {String? title})
→ void
-
Function to set marker locations
-
setPolygonColor(Color? color)
→ void
-
Function to init polygon color
-
setTempToPolygon()
→ void
-
Function to set temporary polygons to polygons
-
setTempToPolyline()
→ void
-
-
setTrackingMode(TrackingMode? mode)
→ void
-
Set current tracking mode
-
toString()
→ String
-
A string representation of this object.
inherited
-
undoLocation()
→ void
-
Function to undo select location in edit mode
-
updateNewMarkerLocation(String id, LatLng _newLoc)
→ void
-
Updating new marker and polygon location
when the marker is dragged