MapScreen class

Inheritance

Constructors

MapScreen({Color? toolColor, Color? polygonColor, IconData? iconLocation, IconData? iconEditMode, IconData? iconCloseEdit, IconData? iconDoneEdit, IconData? iconUndoEdit, IconData? iconGPSPoint, bool? autoEditMode, bool? pointDistance, TrackingMode? trackingMode, LatLng? targetCameraPosition, bool? enableDragMarker})

Properties

autoEditMode → bool?
Property to auto edit mode when maps open
final
enableDragMarker → bool?
Property to enable draggable marker
final
hashCode → int
The hash code for this object.
no setterinherited
iconCloseEdit → IconData?
Property to customize close tool icon
final
iconDoneEdit → IconData?
Property to customize done icon
final
iconEditMode → IconData?
Property to customize edit mode icon
final
iconGPSPoint → IconData?
final
iconLocation → IconData?
Property to customize location icon
final
iconUndoEdit → IconData?
Property to cusstomize undo icon
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
pointDistance → bool?
Property to enable and disable point distance
final
polygonColor → Color?
Property to customize polygon color
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetCameraPosition → LatLng?
If this is null it means user is opting to use GPS tracking
final
toolColor → Color?
Property to customize tool color
final
trackingMode → TrackingMode?
Property to choose tracking mode, you can choose PLANAR or LINEAR
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _MapScreenState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited